@@ -350,7 +350,7 @@ class Dataset(DatasetMeta):
         if not os.path.exists(file_path):
             os.makedirs(file_path, 0o0775)
 
-        file_writer = open(os.path.join(file_path, "output.json"), "w")
+        file_writer = open(os.path.join(file_path, "output.json.tmp"), "w")
         download_helper = DownloadHelper(self._x_api)
 
         count = 0
@@ -402,6 +402,8 @@ class Dataset(DatasetMeta):
 
         file_writer.flush()
         file_writer.close()
+        os.rename(os.path.join(file_path, "output.json.tmp"), os.path.join(file_path, "output.json"))
+
 
     def _get_dataset(
             self,
